@@ -54,7 +54,7 @@ OR PERFORMANCE OF THIS SOFTWARE.
 
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2009 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NX-X11, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -63,7 +63,7 @@ OR PERFORMANCE OF THIS SOFTWARE.
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
+/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -1847,12 +1847,19 @@ Popen(char *command, char *type)
     if (OsVendorStartRedirectErrorFProc != NULL) {
         OsVendorStartRedirectErrorFProc();
     }
+    OsBlockSignals ();
 #endif
     switch (pid = fork()) {
     case -1: 	/* error */
 	close(pdes[0]);
 	close(pdes[1]);
 	xfree(cur);
+#ifdef NX_TRANS_EXIT
+	if (OsVendorEndRedirectErrorFProc != NULL) {
+	    OsVendorEndRedirectErrorFProc();
+	}
+	OsReleaseSignals ();
+#endif
 	return NULL;
     case 0:	/* child */
 	if (setgid(getgid()) == -1)
@@ -1917,12 +1924,18 @@ Popen(char *command, char *type)
 
         #endif
 
+        #ifdef NX_TRANS_EXIT
+	OsReleaseSignals ();
+        #endif
+
 	execl("/bin/sh", "sh", "-c", command, (char *)NULL);
 	_exit(127);
     }
 
+#ifndef NX_TRANS_EXIT
     /* Avoid EINTR during stdio calls */
     OsBlockSignals ();
+#endif
     
     /* parent */
     if (*type == 'r') {
